@@ -361,11 +361,11 @@ int XrdCryptosslRSA::GetPublen()
    return publen;
 }
 //_____________________________________________________________________________
-int XrdCryptosslRSA::ExportPublic(char *&out, int)
+int XrdCryptosslRSA::ExportPublic(char *out, int)
 {
    // Export the public key into buffer out. The length of the buffer should be
-   // at least GetPublen()+1 bytes. If out=0 the buffer is m-allocated internally
-   // and should be freed by the caller.
+   // at least GetPublen()+1 bytes. The buffer out must be passed-by and it
+   // responsability-of the caller.
    // Return 0 in case of success, -1 in case of failure
    EPNAME("RSA::ExportPublic");
 
@@ -375,6 +375,12 @@ int XrdCryptosslRSA::ExportPublic(char *&out, int)
       return -1;
    }
 
+   // Check output buffer
+   if (!out) {
+      DEBUG("output buffer undefined!");
+      return -1;
+   }
+
    // Bio for exporting the pub key
    BIO *bkey = BIO_new(BIO_s_mem());
 
@@ -389,14 +395,6 @@ int XrdCryptosslRSA::ExportPublic(char *&out, int)
       return -1;
    }
 
-   // Check output buffer
-   if (!out) {
-      out = (char *) malloc(lbio+1);
-      if (!out) {
-         DEBUG("problems allocating output buffer");
-         return -1;
-      }
-   }
    // Read key from BIO to buf
    memcpy(out, cbio, lbio);
    // Null terminate
@@ -426,11 +424,11 @@ int XrdCryptosslRSA::GetPrilen()
 }
 
 //_____________________________________________________________________________
-int XrdCryptosslRSA::ExportPrivate(char *&out, int)
+int XrdCryptosslRSA::ExportPrivate(char *out, int)
 {
    // Export the private key into buffer out. The length of the buffer should be
-   // at least GetPrilen()+1 bytes. If out=0 the buffer is m-allocated internally
-   // and should be freed by the caller.
+   // at least GetPrilen()+1 bytes. The buffer out must be passed-by and it
+   // responsability-of the caller.
    // Return 0 in case of success, -1 in case of failure
    EPNAME("RSA::ExportPrivate");
 
@@ -440,6 +438,12 @@ int XrdCryptosslRSA::ExportPrivate(char *&out, int)
       return -1;
    }
 
+   // Check output buffer
+   if (!out) {
+      DEBUG("output buffer undefined!");
+      return -1;
+   }
+
    // Bio for exporting the pub key
    BIO *bkey = BIO_new(BIO_s_mem());
 
@@ -454,14 +458,6 @@ int XrdCryptosslRSA::ExportPrivate(char *&out, int)
       return -1;
    }
 
-   // Check output buffer
-   if (!out) {
-      out = (char *) malloc(lbio+1);
-      if (!out) {
-         DEBUG("problems allocating output buffer");
-         return -1;
-      }
-   }
    // Read key from BIO to buf
    memcpy(out, cbio, lbio);
    // Null terminate
