@@ -46,6 +46,7 @@
 /******************************************************************************/
   
 #define XRDSECSSSID "XrdSecsssID"
+#define XRDSECSSSENDO "XrdSecsssENDORSEMENT"
 
 XrdSysMutex         XrdSecsssID::InitMutex;
 
@@ -204,6 +205,9 @@ XrdSecsssID::sssID *XrdSecsssID::genID(int Secure)
    myID.grps = (Secure || XrdOucUtils::GroupName(getegid(), gBuff, pgSz) == 0)
              ? (char *)"nogroup" : gBuff;
 
+   if (getenv(XRDSECSSSENDO)) 
+     {myID.endorsements = getenv(XRDSECSSSENDO); }
+
 // Just return the sssID
 //
    return genID(&myID);
